==> cloudstructs-0.4.31.tar.gz: package/assets/static-website/origin-request.edge-lambda/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/static-website/origin-request.edge-lambda.ts
var origin_request_edge_lambda_exports = {};
__export(origin_request_edge_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(origin_request_edge_lambda_exports);
var path = __toESM(require("path"));
async function handler(event) {
  const request = event.Records[0].cf.request;
  if (!path.extname(request.uri))
    request.uri = "/index.html";
  return request;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});

==> cloudstructs-0.6.4.tar.gz: package/assets/static-website/origin-request.edge-lambda/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/static-website/origin-request.edge-lambda.ts
var origin_request_edge_lambda_exports = {};
__export(origin_request_edge_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(origin_request_edge_lambda_exports);
var path = __toESM(require("path"));
async function handler(event) {
  const request = event.Records[0].cf.request;
  if (!path.extname(request.uri))
    request.uri = "/index.html";
  return request;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
